==> haskell-stack-1.3.2-18-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.3.2
id: stack-1.3.2-Ig8nstV0hlLI7KAJS311lE
key: stack-1.3.2-Ig8nstV0hlLI7KAJS311lE
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.SolverParser Stack.Options.TestParser
    Stack.Options.Utils Stack.Package Stack.PackageDump
    Stack.PackageIndex Stack.Path Stack.PrettyPrint Stack.Runners
    Stack.SDist Stack.Setup Stack.Setup.Installed Stack.SetupCmd
    Stack.Sig Stack.Sig.GPG Stack.Sig.Sign Stack.Solver
    Stack.Types.Build Stack.Types.BuildPlan Stack.Types.CompilerBuild
    Stack.Types.Urls Stack.Types.Compiler Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.FlagName
    Stack.Types.GhcPkgId Stack.Types.Image Stack.Types.Internal
    Stack.Types.Nix Stack.Types.Package Stack.Types.PackageDump
    Stack.Types.PackageIdentifier Stack.Types.PackageIndex
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.Sig
    Stack.Types.StackT Stack.Types.TemplateName Stack.Types.Version
    Stack.Upgrade Stack.Upload Text.PrettyPrint.Leijen.Extended
    System.Process.Log System.Process.PagerEditor System.Process.Read
    System.Process.Run
abi: ce326b06cbc690307cd9e1e2277b1479
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/stack-1.3.2
hs-libraries: HSstack-1.3.2-Ig8nstV0hlLI7KAJS311lE
depends:
    Cabal-1.24.0.0 aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-KMxMymOUT9FJ5ps7kVkx3u
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-824iGXaP3tL2Ph4TH8girc containers-0.5.7.1
    cryptohash-0.11.9-DHI6HEU0ngdHLXXk1TIe9A
    cryptohash-conduit-0.1.1-IsYhG9U4Fmi54A8lfoYeKQ deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-EbNPoaWgoOPDzN8mAfWK3D
    errors-2.1.3-2XcKFkEhTmRE8K5EsBkhSt
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.1-HeeVckCVl1V9DE6lYqg83I
    fast-logger-2.4.7-5q6cKzCUmhpFUH581aMKto
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
    generic-deriving-1.11.1-A3LIGwpr65P8ydjYiAp7Zd
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
    hit-0.6.3-3yIlxLvBhLGI4jZlIj2GUV
    hpack-0.16.0-3PlnWgarKKlCHiq8Yv0bKZ hpc-0.6.0.3
    http-client-0.5.5-4Matf77UBiO5cGEZXZvoja
    http-client-tls-0.3.3.1-GXjoOdsswOJHTCSYq956ax
    http-conduit-2.2.3-15qfs2XpUkxHtyYvTq6e8Z
    http-types-0.9.1-86VKlfjfTunGvWNFdOLeV5
    lifted-async-0.9.1-Bwox7wRPUwWFz74Tt37a1w
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    microlens-0.4.7.0-6tAYY6Xiw256GM5tdbJVKr
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.1-A1T5ZL9snf64SauyreP6SE
    monad-unlift-0.2.0-ESBXqwmcoXnIlF9dGiiLWr
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.0.0-IErSQpKP3j4oJy1jHSvi1
    path-0.5.11-7PpqyXgI2Nn7ZmvdnSAD7X
    path-io-1.2.2-vkQXuwgdA2NylH0Fs21U
    persistent-2.6-Lw6Qrv3XKz9DVUxp21c7T7
    persistent-sqlite-2.6-4T28kDuNYhCHBcsAqrg7V4
    persistent-template-2.5.1.6-L8I8OFknJ94B45VQtfh03i
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-5lUwfEGXpCWIw8RgU1jwwL
    regex-applicative-text-0.1.0.1-38rcZcyG4EMFvQ12jRt4xV
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.11-Ck0Z7kfzoQA1bcHU9bHvtW
    safe-exceptions-0.1.4.0-8RjIAanjCg2DWmF9F1hZdE
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg store-0.3-DnRSgEaucdR17meoTC87t3
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-binary-0.2.1.1-6SPK6a88IPhHHsLZYIQFEq
    text-metrics-0.2.0-Hn6WpAXJzhNBCvatQNDxSh time-1.6.0.1
    tls-1.3.9-7VPRBtCSFjp9VWbOGeabxj transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-binary-instances-0.2.3.4-5cD0L2W335u9PwXg62l6tz
    yaml-0.8.21.1-AVEYDGyJx5gG3MACMHmcea
    zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stack-1.3.2-45-i686.pkg.tar.xz: usr/share/haskell/register/haskell-stack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stack
version: 1.3.2
id: stack-1.3.2-BGZHTrdMWxa7tGCvlz85p1
key: stack-1.3.2-BGZHTrdMWxa7tGCvlz85p1
license: BSD3
maintainer: manny@fpcomplete.com
homepage: http://haskellstack.org
synopsis: The Haskell Tool Stack
description:
    Please see the README.md for usage information, and
    the wiki on Github for more details.  Also, note that
    the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.
category: Development
author: Commercial Haskell SIG
exposed: True
exposed-modules:
    Control.Concurrent.Execute Data.Aeson.Extended Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.IORef.RunOnce Data.Maybe.Extra Data.Monoid.Extra
    Data.Store.VersionTagged Data.Text.Extra Distribution.Version.Extra
    Network.HTTP.Download Network.HTTP.Download.Verified
    Options.Applicative.Args Options.Applicative.Builder.Extra
    Options.Applicative.Complicated Path.Extra Path.Find Paths_stack
    Stack.Build Stack.Build.Cache Stack.Build.ConstructPlan
    Stack.Build.Execute Stack.Build.Haddock Stack.Build.Installed
    Stack.Build.Source Stack.Build.Target Stack.BuildPlan Stack.Clean
    Stack.Config Stack.Config.Build Stack.Config.Urls
    Stack.Config.Docker Stack.Config.Nix Stack.ConfigCmd
    Stack.Constants Stack.Coverage Stack.Docker Stack.Docker.GlobalDB
    Stack.Dot Stack.Exec Stack.Fetch Stack.FileWatch Stack.GhcPkg
    Stack.Ghci Stack.Ghci.Script Stack.Hoogle Stack.IDE Stack.Image
    Stack.Init Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.ConfigParser
    Stack.Options.DockerParser Stack.Options.DotParser
    Stack.Options.ExecParser Stack.Options.GhcBuildParser
    Stack.Options.GhciParser Stack.Options.GhcVariantParser
    Stack.Options.GlobalParser Stack.Options.HaddockParser
    Stack.Options.HpcReportParser Stack.Options.LogLevelParser
    Stack.Options.NewParser Stack.Options.NixParser
    Stack.Options.PackageParser Stack.Options.ResolverParser
    Stack.Options.SolverParser Stack.Options.TestParser
    Stack.Options.Utils Stack.Package Stack.PackageDump
    Stack.PackageIndex Stack.Path Stack.PrettyPrint Stack.Runners
    Stack.SDist Stack.Setup Stack.Setup.Installed Stack.SetupCmd
    Stack.Sig Stack.Sig.GPG Stack.Sig.Sign Stack.Solver
    Stack.Types.Build Stack.Types.BuildPlan Stack.Types.CompilerBuild
    Stack.Types.Urls Stack.Types.Compiler Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.FlagName
    Stack.Types.GhcPkgId Stack.Types.Image Stack.Types.Internal
    Stack.Types.Nix Stack.Types.Package Stack.Types.PackageDump
    Stack.Types.PackageIdentifier Stack.Types.PackageIndex
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.Sig
    Stack.Types.StackT Stack.Types.TemplateName Stack.Types.Version
    Stack.Upgrade Stack.Upload Text.PrettyPrint.Leijen.Extended
    System.Process.Log System.Process.PagerEditor System.Process.Read
    System.Process.Run
abi: e563a7155355ef3efda4f4a7b60ca70f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/stack-1.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/stack-1.3.2
hs-libraries: HSstack-1.3.2-BGZHTrdMWxa7tGCvlz85p1
depends:
    Cabal-1.24.0.0 aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    annotated-wl-pprint-0.7.0-B6Xo4q6hdW98qIfojQv5XO
    ansi-terminal-0.6.2.3-AKTYR0nthhUCHW4HMZvJFX
    async-2.1.1-9CmNvQft9hOA1w6AR7WdJM
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    base-compat-0.9.1-tmPpmtbHbvIDjFWbkjGrR
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS
    base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY binary-0.8.3.0
    binary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    clock-0.7.2-bxVecpUqndAMeayDi5R9Y
    conduit-1.2.9-IqfCpUleYsf85Inkwdla2
    conduit-extra-1.1.15-9BEhw2PHvUTFj1lUJfHKAK containers-0.5.7.1
    cryptohash-0.11.9-58MQCkevJarJihmcTE8nlX
    cryptohash-conduit-0.1.1-KQHD7rpEs18PtYT4dvXtL deepseq-1.4.2.0
    directory-1.2.6.2 either-4.4.1.1-9JVRXO1hxwop7BCTXURzs
    errors-2.1.3-8ITYmxCImbF1o6OlWIOTbu
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    extra-1.5.1-HeeVckCVl1V9DE6lYqg83I
    fast-logger-2.4.10-2uiHrtzLDm9E79SAJUHzbw
    file-embed-0.0.10-IXfudWSq57y1Athysk5ifZ
    filelock-0.1.0.1-1BXOUOVoqUz7BiI1JXQCnD filepath-1.4.1.0
    fsnotify-0.2.1-AbK6POsDNvc2W7OcESHkcO
    generic-deriving-1.11.1-A3LIGwpr65P8ydjYiAp7Zd
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
    hit-0.6.3-4Nh3yNTSpVBCOdLlYpkPtu
    hpack-0.16.0-BEvZ4oIrfkYI5A9ytDcYFt hpc-0.6.0.3
    http-client-0.5.6-Auo5TBlvhCDIsl575hjQy2
    http-client-tls-0.3.3.1-7WmxQtwFXc1D6MHeSGtCxL
    http-conduit-2.2.3-1M3ZSKgvOkUH9nEqMRMQJb
    http-types-0.9.1-IFoDf4vkjVIKXmx1LMyAfY
    lifted-async-0.9.1.1-YhJ9WH1OyT5480945Dhv4
    lifted-base-0.2.3.10-GN8bGJb6NKpLjv5n9gQH0C
    microlens-0.4.7.0-6tAYY6Xiw256GM5tdbJVKr
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.20.2-JTAIQ2hISya9krzRihq4vG
    monad-unlift-0.2.0-G7TSA42IVcaLvASvDhkbso
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    open-browser-0.2.1.0-L9zpSlcLT7P1KSvFrOA2Vw
    optparse-applicative-0.13.1.0-IMOgMyEFJ9R7Y6gGL71zwn
    path-0.5.12-LtMPIoQzInzFU8SzsehF9u
    path-io-1.2.2-BrNPvJwUxJU4Z7e6O4f1uz
    persistent-2.6-IW9EjImAw3vJ6wSbFCA7c6
    persistent-sqlite-2.6.0.1-2eXdYBWcHQp5sTlICorXJC
    persistent-template-2.5.1.6-52x9O9brU3X39av9F2UsbA
    pid1-0.1.0.1-8mn4OgqkObOJ7nO3SZJUm pretty-1.1.3.3 process-1.4.2.0
    project-template-0.2.0-7OtokhXG7zBIK4dgiwow4
    regex-applicative-text-0.1.0.1-38rcZcyG4EMFvQ12jRt4xV
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    retry-0.7.4.2-GWFkfUBDuq8slJnBN66V2
    safe-0.3.14-ALdwhNEer7fKnF5VYCbXfH
    safe-exceptions-0.1.4.0-8RjIAanjCg2DWmF9F1hZdE
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    split-0.2.3.1-IJKK4pOCYGKud0jZImZke
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    store-0.3.1-7DTfbDaue4kKtkbIaYQLbT
    streaming-commons-0.1.17-JBMCKUjr3AjHIyRG4GSmU7
    tar-0.5.0.3-Lj53UbIqLpELgGWYmsAfKo template-haskell-2.11.0.0
    temporary-1.2.0.4-2ZGJgvUMoC3CqxertnjRxn
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    text-binary-0.2.1.1-6SPK6a88IPhHHsLZYIQFEq
    text-metrics-0.2.0-Hn6WpAXJzhNBCvatQNDxSh time-1.6.0.1
    tls-1.3.9-9hJarkwYzYhCvX1UB21o6G transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unicode-transforms-0.2.1-8q7tL2skgYi8hmY9m3wNwt unix-2.7.2.0
    unix-compat-0.4.3.1-GamCWWfiT0318wIeUlpE1K
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    vector-binary-instances-0.2.3.4-5cD0L2W335u9PwXg62l6tz
    yaml-0.8.22-INeHbn75CrTI4wcMhFaML4
    zip-archive-0.3.0.5-4R8dq2PHAV4JpIvEapAb0Q
    zlib-0.6.1.2-1dMv6Gv8Q4W22Ei4thcEsU
haddock-interfaces: /usr/share/doc/stack/html/stack.haddock
haddock-html: /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
